==> gramps-3.0.1.tgz: share/gramps/Filters/Rules/Person/_NoBirthdate.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# $Id: _NoBirthdate.py 9912 2008-01-22 09:17:46Z acraphae $

#-------------------------------------------------------------------------
#
# Standard Python modules
#
#-------------------------------------------------------------------------
from gettext import gettext as _

#-------------------------------------------------------------------------
#
# GRAMPS modules
#
#-------------------------------------------------------------------------
from Filters.Rules._Rule import Rule

#-------------------------------------------------------------------------
# "People without a birth date"
#-------------------------------------------------------------------------
class NoBirthdate(Rule):
    """People without a birth date"""

    name        = _('People without a known birth date')
    description = _("Matches people without a known birthdate")
    category    = _('General filters')

    def apply(self,db,person):
        birth_ref = person.get_birth_ref()
        if not birth_ref:
            return True
        birth = db.get_event_from_handle(birth_ref.ref)
        if not birth.get_date_object():
            return True
        return False

==> gramps-3.1.3.tgz: share/gramps/Filters/Rules/Person/_NoBirthdate.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# $Id: _NoBirthdate.py 11619 2009-01-13 22:25:05Z dsblank $

#-------------------------------------------------------------------------
#
# Standard Python modules
#
#-------------------------------------------------------------------------
from gettext import gettext as _

#-------------------------------------------------------------------------
#
# GRAMPS modules
#
#-------------------------------------------------------------------------
from Filters.Rules._Rule import Rule

#-------------------------------------------------------------------------
# "People without a birth date"
#-------------------------------------------------------------------------
class NoBirthdate(Rule):
    """People without a birth date"""

    name        = _('People without a known birth date')
    description = _("Matches people without a known birthdate")
    category    = _('General filters')

    def apply(self,db,person):
        birth_ref = person.get_birth_ref()
        if not birth_ref:
            return True
        birth = db.get_event_from_handle(birth_ref.ref)
        if birth:
            birth_obj = birth.get_date_object()
            if not birth_obj:
                return True
            if birth_obj.sortval == 0:
                return True
        return False
